@@ -29,8 +29,17 @@ CD_LOCATIONS = {
     "partition",
 }
 
+POLICY_IGNORE_ALL_FAILURES = "ignoreallfailures"
+
+SAN_POLICY_ONLINE_STR = 'OnlineAll'
+SAN_POLICY_OFFLINE_STR = 'OfflineAll'
+SAN_POLICY_OFFLINE_SHARED_STR = 'OfflineShared'
+
 CLEAR_TEXT_INJECTED_ONLY = 'clear_text_injected_only'
 ALWAYS_CHANGE = 'always'
 NEVER_CHANGE = 'no'
 LOGON_PASSWORD_CHANGE_OPTIONS = [CLEAR_TEXT_INJECTED_ONLY, NEVER_CHANGE,
                                  ALWAYS_CHANGE]
+
+VOL_ACT_KMS = "KMS"
+VOL_ACT_AVMA = "AVMA"
