@@ -137,6 +137,9 @@ class BaseMetadataService(object):
         in the namedtuple defined above.
         """
 
+    def get_admin_username(self):
+        pass
+
     def get_admin_password(self):
         pass
 
@@ -151,6 +154,9 @@ class BaseMetadataService(object):
     def post_password(self, enc_password_b64):
         pass
 
+    def get_winrm_listeners_configuration(self):
+        pass
+
     def get_client_auth_certs(self):
         pass
 
@@ -183,6 +189,23 @@ class BaseMetadataService(object):
         """
         return False
 
+    @property
+    def can_post_rdp_cert_thumbprint(self):
+        return False
+
+    def post_rdp_cert_thumbprint(self, thumbprint):
+        pass
+
+    def get_kms_host(self):
+        pass
+
+    def get_use_avma_licensing(self):
+        pass
+
+    def get_enable_automatic_updates(self):
+        """Check if the metadata provider enforces automatic updates."""
+        pass
+
 
 class BaseHTTPMetadataService(BaseMetadataService):
 
