@@ -18,6 +18,7 @@ from ctypes import wintypes
 import os
 import re
 import struct
+import subprocess
 import time
 
 from oslo_log import log as oslo_logging
@@ -57,6 +58,7 @@ Ws2_32 = ctypes.windll.Ws2_32
 setupapi = ctypes.windll.setupapi
 msvcrt = ctypes.cdll.msvcrt
 ntdll = ctypes.windll.ntdll
+secur32 = ctypes.windll.secur32
 
 
 class Win32_PROFILEINFO(ctypes.Structure):
@@ -144,12 +146,63 @@ class Win32_STORAGE_DEVICE_NUMBER(ctypes.Structure):
     ]
 
 
+class Win32_STARTUPINFO_W(ctypes.Structure):
+    _fields_ = [
+        ('cb', wintypes.DWORD),
+        ('lpReserved', wintypes.LPWSTR),
+        ('lpDesktop', wintypes.LPWSTR),
+        ('lpTitle', wintypes.LPWSTR),
+        ('dwX', wintypes.DWORD),
+        ('dwY', wintypes.DWORD),
+        ('dwXSize', wintypes.DWORD),
+        ('dwYSize', wintypes.DWORD),
+        ('dwXCountChars', wintypes.DWORD),
+        ('dwYCountChars', wintypes.DWORD),
+        ('dwFillAttribute', wintypes.DWORD),
+        ('dwFlags', wintypes.DWORD),
+        ('wShowWindow', wintypes.WORD),
+        ('cbReserved2', wintypes.WORD),
+        ('lpReserved2', ctypes.POINTER(wintypes.BYTE)),
+        ('hStdInput', wintypes.HANDLE),
+        ('hStdOutput', wintypes.HANDLE),
+        ('hStdError', wintypes.HANDLE),
+    ]
+
+
+class Win32_PROCESS_INFORMATION(ctypes.Structure):
+    _fields_ = [
+        ('hProcess', wintypes.HANDLE),
+        ('hThread', wintypes.HANDLE),
+        ('dwProcessId', wintypes.DWORD),
+        ('dwThreadId', wintypes.DWORD),
+    ]
+
+
+advapi32.CreateProcessAsUserW.argtypes = [wintypes.HANDLE,
+                                          wintypes.LPCWSTR,
+                                          wintypes.LPWSTR,
+                                          ctypes.c_void_p,
+                                          ctypes.c_void_p,
+                                          wintypes.BOOL,
+                                          wintypes.DWORD,
+                                          ctypes.c_void_p,
+                                          wintypes.LPCWSTR,
+                                          ctypes.POINTER(
+                                              Win32_STARTUPINFO_W),
+                                          ctypes.POINTER(
+                                              Win32_PROCESS_INFORMATION)]
+advapi32.CreateProcessAsUserW.restype = wintypes.BOOL
+
 msvcrt.malloc.argtypes = [ctypes.c_size_t]
 msvcrt.malloc.restype = ctypes.c_void_p
 
 msvcrt.free.argtypes = [ctypes.c_void_p]
 msvcrt.free.restype = None
 
+ntdll.RtlGetVersion.argtypes = [
+    ctypes.POINTER(Win32_OSVERSIONINFOEX_W)]
+ntdll.RtlGetVersion.restype = wintypes.DWORD
+
 ntdll.RtlVerifyVersionInfo.argtypes = [
     ctypes.POINTER(Win32_OSVERSIONINFOEX_W),
     wintypes.DWORD, wintypes.ULARGE_INTEGER]
@@ -193,6 +246,18 @@ kernel32.HeapFree.argtypes = [wintypes.HANDLE, wintypes.DWORD,
                               wintypes.LPVOID]
 kernel32.HeapFree.restype = wintypes.BOOL
 
+kernel32.GetVolumeNameForVolumeMountPointW.argtypes = [wintypes.LPCWSTR,
+                                                       wintypes.LPWSTR,
+                                                       wintypes.DWORD]
+kernel32.GetVolumeNameForVolumeMountPointW.restype = wintypes.BOOL
+
+kernel32.GetVolumePathNamesForVolumeNameW.argtypes = [wintypes.LPCWSTR,
+                                                      wintypes.LPWSTR,
+                                                      wintypes.DWORD,
+                                                      ctypes.POINTER(
+                                                          wintypes.DWORD)]
+kernel32.GetVolumePathNamesForVolumeNameW.restype = wintypes.BOOL
+
 iphlpapi.GetIpForwardTable.argtypes = [
     ctypes.POINTER(Win32_MIB_IPFORWARDTABLE),
     ctypes.POINTER(wintypes.ULONG),
@@ -201,6 +266,11 @@ iphlpapi.GetIpForwardTable.restype = wintypes.DWORD
 
 Ws2_32.inet_ntoa.restype = ctypes.c_char_p
 
+secur32.GetUserNameExW.argtypes = [wintypes.DWORD,
+                                   wintypes.LPWSTR,
+                                   ctypes.POINTER(wintypes.ULONG)]
+secur32.GetUserNameExW.restype = wintypes.BOOL
+
 setupapi.SetupDiGetClassDevsW.argtypes = [ctypes.POINTER(disk.GUID),
                                           wintypes.LPCWSTR,
                                           wintypes.HANDLE,
@@ -240,9 +310,12 @@ GUID_DEVINTERFACE_DISK = disk.GUID(0x53f56307, 0xb6bf, 0x11d0, 0x94, 0xf2,
 class WindowsUtils(base.BaseOSUtils):
     NERR_GroupNotFound = 2220
     NERR_UserNotFound = 2221
+    ERROR_PATH_NOT_FOUND = 3
     ERROR_ACCESS_DENIED = 5
     ERROR_INSUFFICIENT_BUFFER = 122
+    ERROR_INVALID_NAME = 123
     ERROR_NO_DATA = 232
+    ERROR_MORE_DATA = 234
     ERROR_NO_SUCH_MEMBER = 1387
     ERROR_MEMBER_IN_ALIAS = 1378
     ERROR_INVALID_MEMBER = 1388
@@ -269,6 +342,18 @@ class WindowsUtils(base.BaseOSUtils):
 
     DRIVE_CDROM = 5
 
+    INFINITE = 0xFFFFFFFF
+
+    CREATE_NEW_CONSOLE = 0x10
+
+    LOGON32_LOGON_BATCH = 4
+    LOGON32_LOGON_INTERACTIVE = 2
+    LOGON32_LOGON_SERVICE = 5
+
+    LOGON32_PROVIDER_DEFAULT = 0
+
+    EXTENDED_NAME_FORMAT_SAM_COMPATIBLE = 2
+
     SERVICE_STATUS_STOPPED = "Stopped"
     SERVICE_STATUS_START_PENDING = "Start Pending"
     SERVICE_STATUS_STOP_PENDING = "Stop Pending"
@@ -282,6 +367,31 @@ class WindowsUtils(base.BaseOSUtils):
     SERVICE_START_MODE_MANUAL = "Manual"
     SERVICE_START_MODE_DISABLED = "Disabled"
 
+    _SERVICE_START_TYPE_MAP = {
+        SERVICE_START_MODE_AUTOMATIC:
+        win32service.SERVICE_AUTO_START,
+        SERVICE_START_MODE_MANUAL:
+        win32service.SERVICE_DEMAND_START,
+        SERVICE_START_MODE_DISABLED:
+        win32service.SERVICE_DISABLED}
+
+    _SERVICE_STATUS_MAP = {
+        win32service.SERVICE_CONTINUE_PENDING:
+        SERVICE_STATUS_CONTINUE_PENDING,
+        win32service.SERVICE_PAUSE_PENDING:
+        SERVICE_STATUS_PAUSE_PENDING,
+        win32service.SERVICE_PAUSED:
+        SERVICE_STATUS_PAUSED,
+        win32service.SERVICE_RUNNING:
+        SERVICE_STATUS_RUNNING,
+        win32service.SERVICE_START_PENDING:
+        SERVICE_STATUS_START_PENDING,
+        win32service.SERVICE_STOP_PENDING:
+        SERVICE_STATUS_STOP_PENDING,
+        win32service.SERVICE_STOPPED:
+        SERVICE_STATUS_STOPPED,
+    }
+
     ComputerNamePhysicalDnsHostname = 5
 
     _config_key = 'SOFTWARE\\Cloudbase Solutions\\Cloudbase-Init\\'
@@ -326,6 +436,39 @@ class WindowsUtils(base.BaseOSUtils):
             raise exception.CloudbaseInitException(
                 "Create user failed: %s" % ex.args[2])
 
+    def rename_user(self, username, new_username):
+        user_info = {
+            "name": new_username,
+        }
+        try:
+            win32net.NetUserSetInfo(None, username, 0, user_info)
+        except win32net.error as ex:
+            if ex.args[0] == self.NERR_UserNotFound:
+                raise exception.ItemNotFoundException(
+                    "User not found: %s" % username)
+            else:
+                raise exception.CloudbaseInitException(
+                    "Renaming user failed: %s" % ex.args[2])
+
+    def enum_users(self):
+        usernames = []
+        resume_handle = 0
+        while True:
+            try:
+                users_info, total, resume_handle = win32net.NetUserEnum(
+                    None, 0, win32netcon.FILTER_NORMAL_ACCOUNT, resume_handle)
+            except win32net.error as ex:
+                raise exception.CloudbaseInitException(
+                    "Enumerating users failed: %s" % ex.args[2])
+
+            usernames += [u["name"] for u in users_info]
+            if not resume_handle:
+                return usernames
+
+    def is_builtin_admin(self, username):
+        sid = self.get_user_sid(username)
+        return sid and sid.startswith(u"S-1-5-") and sid.endswith(u"-500")
+
     def _get_user_info(self, username, level):
         try:
             return win32net.NetUserGetInfo(None, username, level)
@@ -392,7 +535,7 @@ class WindowsUtils(base.BaseOSUtils):
         lmi.lgrmi3_domainandname = six.text_type(username)
 
         ret_val = netapi32.NetLocalGroupAddMembers(0, six.text_type(groupname),
-                                                   3, ctypes.addressof(lmi), 1)
+                                                   3, ctypes.pointer(lmi), 1)
 
         if ret_val == self.NERR_GroupNotFound:
             raise exception.CloudbaseInitException('Group not found')
@@ -417,11 +560,17 @@ class WindowsUtils(base.BaseOSUtils):
             pass
 
     def create_user_logon_session(self, username, password, domain='.',
-                                  load_profile=True):
+                                  load_profile=True,
+                                  logon_type=LOGON32_LOGON_INTERACTIVE):
+        LOG.debug("Creating logon session for user: %(domain)s\\%(username)s",
+                  {"username": username, "domain": domain})
+
         token = wintypes.HANDLE()
         ret_val = advapi32.LogonUserW(six.text_type(username),
                                       six.text_type(domain),
-                                      six.text_type(password), 2, 0,
+                                      six.text_type(password),
+                                      logon_type,
+                                      self.LOGON32_PROVIDER_DEFAULT,
                                       ctypes.byref(token))
         if not ret_val:
             raise exception.WindowsCloudbaseInitException(
@@ -439,6 +588,70 @@ class WindowsUtils(base.BaseOSUtils):
 
         return token
 
+    def get_current_user(self):
+        """Get the user account name from the underlying instance."""
+        buf_len = wintypes.ULONG(512)
+        buf = ctypes.create_unicode_buffer(512)
+
+        ret_val = secur32.GetUserNameExW(
+            self.EXTENDED_NAME_FORMAT_SAM_COMPATIBLE,
+            buf, ctypes.byref(buf_len))
+        if not ret_val:
+            raise exception.WindowsCloudbaseInitException(
+                "GetUserNameExW failed: %r")
+
+        return buf.value.split("\\")
+
+    def execute_process_as_user(self, token, args, wait=True,
+                                new_console=False):
+        """Executes processes as an user.
+
+        :param token: Represents the user logon session token, resulted from
+                      running the 'create_user_logon_session' method.
+        :param args: The arguments with which the process will be runned with.
+        :param wait: Specifies if it's needed to wait for the process
+                     handler to finish up running all the operations
+                     on the process object.
+        :param new_console: Specifies whether the process should run
+                            under a new console or not.
+        :return: The exit code value resulted from the running process.
+        :rtype: int
+        """
+        LOG.debug("Executing process as user, command line: %s", args)
+
+        proc_info = Win32_PROCESS_INFORMATION()
+        startup_info = Win32_STARTUPINFO_W()
+        startup_info.cb = ctypes.sizeof(Win32_STARTUPINFO_W)
+        startup_info.lpDesktop = ""
+
+        flags = self.CREATE_NEW_CONSOLE if new_console else 0
+        cmdline = ctypes.create_unicode_buffer(subprocess.list2cmdline(args))
+
+        try:
+            ret_val = advapi32.CreateProcessAsUserW(
+                token, None, cmdline, None, None, False, flags, None, None,
+                ctypes.byref(startup_info), ctypes.byref(proc_info))
+            if not ret_val:
+                raise exception.WindowsCloudbaseInitException(
+                    "CreateProcessAsUserW failed: %r")
+
+            if wait and proc_info.hProcess:
+                kernel32.WaitForSingleObject(
+                    proc_info.hProcess, self.INFINITE)
+
+                exit_code = wintypes.DWORD()
+                if not kernel32.GetExitCodeProcess(
+                        proc_info.hProcess, ctypes.byref(exit_code)):
+                    raise exception.WindowsCloudbaseInitException(
+                        "GetExitCodeProcess failed: %r")
+
+                return exit_code.value
+        finally:
+            if proc_info.hProcess:
+                kernel32.CloseHandle(proc_info.hProcess)
+            if proc_info.hThread:
+                kernel32.CloseHandle(proc_info.hThread)
+
     def close_user_logon_session(self, token):
         kernel32.CloseHandle(token)
 
@@ -677,74 +890,121 @@ class WindowsUtils(base.BaseOSUtils):
             else:
                 raise ex
 
-    def _get_service(self, service_name):
-        conn = wmi.WMI(moniker='//./root/cimv2')
-        service_list = conn.Win32_Service(Name=service_name)
-        if len(service_list):
-            return service_list[0]
-
     def check_service_exists(self, service_name):
+        LOG.debug("Checking if service exists: %s", service_name)
         try:
             with self._get_service_handle(service_name):
                 return True
         except pywintypes.error as ex:
-            print(ex)
             if ex.winerror == winerror.ERROR_SERVICE_DOES_NOT_EXIST:
                 return False
             raise
 
     def get_service_status(self, service_name):
-        service = self._get_service(service_name)
-        return service.State
+        LOG.debug("Getting service status for: %s", service_name)
+        with self._get_service_handle(
+                service_name, win32service.SERVICE_QUERY_STATUS) as hs:
+            service_status = win32service.QueryServiceStatusEx(hs)
+            state = service_status['CurrentState']
+
+            return self._SERVICE_STATUS_MAP.get(
+                state, WindowsUtils.SERVICE_STATUS_UNKNOWN)
 
     def get_service_start_mode(self, service_name):
-        service = self._get_service(service_name)
-        return service.StartMode
+        LOG.debug("Getting service start mode for: %s", service_name)
+        with self._get_service_handle(
+                service_name, win32service.SERVICE_QUERY_CONFIG) as hs:
+            service_config = win32service.QueryServiceConfig(hs)
+
+            start_type = service_config[1]
+            return [k for k, v in self._SERVICE_START_TYPE_MAP.items()
+                    if v == start_type][0]
 
     def set_service_start_mode(self, service_name, start_mode):
         # TODO(alexpilotti): Handle the "Delayed Start" case
-        service = self._get_service(service_name)
-        (ret_val,) = service.ChangeStartMode(start_mode)
-        if ret_val != 0:
-            raise exception.CloudbaseInitException(
-                'Setting service %(service_name)s start mode failed with '
-                'return value: %(ret_val)d' % {'service_name': service_name,
-                                               'ret_val': ret_val})
+        LOG.debug("Setting service start mode for: %s", service_name)
+        start_type = self._get_win32_start_type(start_mode)
+
+        with self._get_service_handle(
+                service_name, win32service.SERVICE_CHANGE_CONFIG) as hs:
+            win32service.ChangeServiceConfig(
+                hs, win32service.SERVICE_NO_CHANGE,
+                start_type, win32service.SERVICE_NO_CHANGE,
+                None, None, False, None, None, None, None)
 
     def start_service(self, service_name):
         LOG.debug('Starting service %s', service_name)
-        service = self._get_service(service_name)
-        (ret_val,) = service.StartService()
-        if ret_val != 0:
-            raise exception.CloudbaseInitException(
-                'Starting service %(service_name)s failed with return value: '
-                '%(ret_val)d' % {'service_name': service_name,
-                                 'ret_val': ret_val})
+        with self._get_service_handle(
+                service_name, win32service.SERVICE_START) as hs:
+            win32service.StartService(hs, service_name)
 
-    def stop_service(self, service_name):
+    def stop_service(self, service_name, wait=False):
         LOG.debug('Stopping service %s', service_name)
-        service = self._get_service(service_name)
-        (ret_val,) = service.StopService()
-        if ret_val != 0:
-            raise exception.CloudbaseInitException(
-                'Stopping service %(service_name)s failed with return value:'
-                ' %(ret_val)d' % {'service_name': service_name,
-                                  'ret_val': ret_val})
+        with self._get_service_handle(
+                service_name,
+                win32service.SERVICE_STOP |
+                win32service.SERVICE_QUERY_STATUS) as hs:
+            win32service.ControlService(hs, win32service.SERVICE_CONTROL_STOP)
+            if wait:
+                while True:
+                    service_status = win32service.QueryServiceStatusEx(hs)
+                    state = service_status['CurrentState']
+                    if state == win32service.SERVICE_STOPPED:
+                        return
+                    time.sleep(.1)
+
+    @staticmethod
+    @contextlib.contextmanager
+    def _get_service_control_manager(
+            scm_access=win32service.SC_MANAGER_CONNECT):
+        hscm = win32service.OpenSCManager(None, None, scm_access)
+        try:
+            yield hscm
+        finally:
+            win32service.CloseServiceHandle(hscm)
 
     @staticmethod
     @contextlib.contextmanager
     def _get_service_handle(service_name,
                             service_access=win32service.SERVICE_QUERY_CONFIG,
                             scm_access=win32service.SC_MANAGER_CONNECT):
-        hscm = win32service.OpenSCManager(None, None, scm_access)
-        hs = None
-        try:
+        with WindowsUtils._get_service_control_manager(scm_access) as hscm:
             hs = win32service.OpenService(hscm, service_name, service_access)
-            yield hs
-        finally:
-            if hs:
+            try:
+                yield hs
+            finally:
                 win32service.CloseServiceHandle(hs)
-            win32service.CloseServiceHandle(hscm)
+
+    @staticmethod
+    def _get_win32_start_type(start_mode):
+        start_type = WindowsUtils._SERVICE_START_TYPE_MAP.get(start_mode)
+        if not start_type:
+            raise exception.InvalidStateException(
+                "Invalid service start mode: %s" % start_mode)
+        return start_type
+
+    def create_service(self, service_name, display_name, path, start_mode,
+                       username=None, password=None):
+        LOG.debug('Creating service %s', service_name)
+        start_type = self._get_win32_start_type(start_mode)
+
+        with WindowsUtils._get_service_control_manager(
+                scm_access=win32service.SC_MANAGER_CREATE_SERVICE) as hscm:
+            hs = win32service.CreateService(
+                hscm, service_name, display_name,
+                win32service.SERVICE_ALL_ACCESS,
+                win32service.SERVICE_WIN32_OWN_PROCESS,
+                start_type,
+                win32service.SERVICE_ERROR_NORMAL,
+                path, None, False, None,
+                username, password)
+            win32service.CloseServiceHandle(hs)
+
+    def delete_service(self, service_name):
+        LOG.debug('Deleting service %s', service_name)
+        with self._get_service_handle(
+                service_name, win32service.SERVICE_ALL_ACCESS) as hs:
+            win32service.DeleteService(hs)
 
     def set_service_credentials(self, service_name, username, password):
         LOG.debug('Setting service credentials: %s', service_name)
@@ -773,19 +1033,19 @@ class WindowsUtils(base.BaseOSUtils):
         """This is needed to avoid pass the hash attacks."""
         if not self.check_service_exists(self._service_name):
             LOG.info("Service does not exist: %s", self._service_name)
-            return False
+            return None
 
         service_username = self.get_service_username(self._service_name)
         # Ignore builtin accounts
         if "\\" not in service_username:
             LOG.info("Skipping password reset, service running as a built-in "
                      "account: %s", service_username)
-            return False
+            return None
         domain, username = service_username.split('\\')
         if domain != ".":
             LOG.info("Skipping password reset, service running as a domain "
                      "account: %s", service_username)
-            return False
+            return None
 
         LOG.debug('Resetting password for service user: %s', service_username)
         maximum_length = self.get_maximum_password_length()
@@ -793,7 +1053,7 @@ class WindowsUtils(base.BaseOSUtils):
         self.set_user_password(username, password)
         self.set_service_credentials(
             self._service_name, service_username, password)
-        return True
+        return domain, username, password
 
     def terminate(self):
         # Wait for the service to start. Polling the service "Started" property
@@ -885,6 +1145,23 @@ class WindowsUtils(base.BaseOSUtils):
             raise exception.CloudbaseInitException(
                 'Unable to add route: %s' % err)
 
+    def get_os_version(self):
+        vi = Win32_OSVERSIONINFOEX_W()
+        vi.dwOSVersionInfoSize = ctypes.sizeof(Win32_OSVERSIONINFOEX_W)
+        ret_val = ntdll.RtlGetVersion(ctypes.byref(vi))
+        if ret_val:
+            raise exception.WindowsCloudbaseInitException(
+                "RtlGetVersion failed with error: %s" % ret_val)
+        return {"major_version": vi.dwMajorVersion,
+                "minor_version": vi.dwMinorVersion,
+                "build_number": vi.dwBuildNumber,
+                "platform_id": vi.dwPlatformId,
+                "csd_version": vi.szCSDVersion,
+                "service_pack_major": vi.wServicePackMajor,
+                "service_pack_minor": vi.wServicePackMinor,
+                "suite_mask": vi.wSuiteMask,
+                "product_type": vi.wProductType}
+
     def check_os_version(self, major, minor, build=0):
         vi = Win32_OSVERSIONINFOEX_W()
         vi.dwOSVersionInfoSize = ctypes.sizeof(Win32_OSVERSIONINFOEX_W)
@@ -916,6 +1193,38 @@ class WindowsUtils(base.BaseOSUtils):
         if ret_val:
             return label.value
 
+    def get_volume_path_names_by_mount_point(self, mount_point):
+        max_volume_name_len = 50
+        volume_name = ctypes.create_unicode_buffer(max_volume_name_len)
+
+        if not kernel32.GetVolumeNameForVolumeMountPointW(
+                six.text_type(mount_point), volume_name,
+                max_volume_name_len):
+            if kernel32.GetLastError() in [self.ERROR_INVALID_NAME,
+                                           self.ERROR_PATH_NOT_FOUND]:
+                raise exception.ItemNotFoundException(
+                    "Mount point not found: %s" % mount_point)
+            else:
+                raise exception.WindowsCloudbaseInitException(
+                    "Failed to get volume name for mount point: %s. "
+                    "Error: %%r" % mount_point)
+
+        volume_path_names_len = wintypes.DWORD(100)
+        while True:
+            volume_path_names = ctypes.create_unicode_buffer(
+                volume_path_names_len.value)
+            if not kernel32.GetVolumePathNamesForVolumeNameW(
+                    volume_name, volume_path_names, volume_path_names_len,
+                    ctypes.byref(volume_path_names_len)):
+                if kernel32.GetLastError() == self.ERROR_MORE_DATA:
+                    continue
+                else:
+                    raise exception.WindowsCloudbaseInitException(
+                        "Failed to get path names for volume name: %s."
+                        "Error: %%r" % volume_name.value)
+            return [n for n in volume_path_names[
+                :volume_path_names_len.value - 1].split('\0') if n]
+
     def generate_random_password(self, length):
         while True:
             pwd = super(WindowsUtils, self).generate_random_password(length)
@@ -943,7 +1252,7 @@ class WindowsUtils(base.BaseOSUtils):
 
         return values
 
-    def _get_logical_drives(self):
+    def get_logical_drives(self):
         buf_size = self.MAX_PATH
         buf = ctypes.create_unicode_buffer(buf_size + 1)
         buf_len = kernel32.GetLogicalDriveStringsW(buf_size, buf)
@@ -954,7 +1263,7 @@ class WindowsUtils(base.BaseOSUtils):
         return self._split_str_buf_list(buf, buf_len)
 
     def get_cdrom_drives(self):
-        drives = self._get_logical_drives()
+        drives = self.get_logical_drives()
         return [d for d in drives if kernel32.GetDriveTypeW(d) ==
                 self.DRIVE_CDROM]
 
@@ -1186,3 +1495,84 @@ class WindowsUtils(base.BaseOSUtils):
             raise exception.CloudbaseInitException(
                 "The given timezone name is unrecognised: %r" % timezone_name)
         timezone.Timezone(windows_name).set(self)
+
+    def is_real_time_clock_utc(self):
+        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
+                            'SYSTEM\\CurrentControlSet\\Control\\'
+                            'TimeZoneInformation') as key:
+            try:
+                utc = winreg.QueryValueEx(key, 'RealTimeIsUniversal')[0]
+                return utc != 0
+            except WindowsError as ex:
+                if ex.winerror == 2:
+                    return False
+                raise
+
+    def set_real_time_clock_utc(self, utc):
+        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
+                            'SYSTEM\\CurrentControlSet\\Control\\'
+                            'TimeZoneInformation',
+                            0, winreg.KEY_ALL_ACCESS) as key:
+            winreg.SetValueEx(key, 'RealTimeIsUniversal', 0,
+                              winreg.REG_DWORD, 1 if utc else 0)
+
+    def get_page_files(self):
+        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
+                            'SYSTEM\\CurrentControlSet\\Control\\'
+                            'Session Manager\\Memory Management') as key:
+            values = winreg.QueryValueEx(key, 'PagingFiles')[0]
+
+        page_files = []
+        for value in values:
+            v = value.split(" ")
+            path = v[0]
+            min_size_mb = int(v[1]) if len(v) > 1 else 0
+            max_size_mb = int(v[2]) if len(v) > 2 else 0
+            page_files.append((path, min_size_mb, max_size_mb))
+        return page_files
+
+    def set_page_files(self, page_files):
+        values = []
+        for path, min_size_mb, max_size_mb in page_files:
+            values.append("%s %d %d" % (path, min_size_mb, max_size_mb))
+
+        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
+                            'SYSTEM\\CurrentControlSet\\Control\\'
+                            'Session Manager\\Memory Management',
+                            0, winreg.KEY_ALL_ACCESS) as key:
+            winreg.SetValueEx(key, 'PagingFiles', 0,
+                              winreg.REG_MULTI_SZ, values)
+
+    def enable_trim(self, enable):
+        """Enables or disables TRIM delete notifications."""
+        args = ["fsutil.exe", "behavior", "set", "disabledeletenotify",
+                "0" if enable else "1"]
+        (out, err, ret_val) = self.execute_system32_process(args)
+        if ret_val:
+            raise exception.CloudbaseInitException(
+                'TRIM configurating failed.\nOutput: %(out)s\nError:'
+                ' %(err)s' % {'out': out, 'err': err})
+
+    def set_path_admin_acls(self, path):
+        LOG.debug("Assigning admin ACLs on path: %s", path)
+        # Sets ACLs for "NT AUTHORITY\SYSTEM" and "BUILTIN\Administrators"
+        # TODO(alexpilotti): replace with SetNamedSecurityInfo
+        (out, err, ret_val) = self.execute_system32_process([
+            "icacls.exe", path, "/inheritance:r", "/grant:r",
+            "*S-1-5-18:(OI)(CI)F", "*S-1-5-32-544:(OI)(CI)F"])
+        if ret_val:
+            raise exception.CloudbaseInitException(
+                'Failed to set path ACLs.\nOutput: %(out)s\nError:'
+                ' %(err)s' % {'out': out, 'err': err})
+
+    def take_path_ownership(self, path, username=None):
+        if username:
+            raise NotImplementedError()
+        LOG.debug("Taking ownership of path: %s", path)
+        # TODO(alexpilotti): replace with SetNamedSecurityInfo
+        (out, err, ret_val) = self.execute_system32_process([
+            "takeown.exe", "/F", path])
+        if ret_val:
+            raise exception.CloudbaseInitException(
+                'Failed to take path ownership.\nOutput: %(out)s\nError:'
+                ' %(err)s' % {'out': out, 'err': err})
