@@ -23,6 +23,7 @@ try:
 except ImportError:
     import mock
 
+from cloudbaseinit import exception
 from cloudbaseinit.metadata.services import base as metadata_services_base
 from cloudbaseinit.plugins.common import base
 from cloudbaseinit.plugins.common import userdata
@@ -51,6 +52,42 @@ class UserDataPluginTest(unittest.TestCase):
         self.fake_data = fake_json_response.get_fake_metadata_json(
             '2013-04-04')
 
+    @mock.patch('cloudbaseinit.osutils.factory.get_os_utils')
+    @mock.patch('os.unlink')
+    @mock.patch('os.path.isdir')
+    @mock.patch('os.makedirs')
+    @mock.patch('os.path.dirname')
+    @mock.patch('os.path.exists')
+    def _test_write_userdata(self, mock_exists, mock_dirname, mock_makedirs,
+                             mock_is_dir, mock_unlink, mock_get_os_utils,
+                             os_exists_effects=None, is_dir=True):
+        mock_userdata = str(mock.sentinel.user_data)
+        mock_user_data_path = str(mock.sentinel.user_data_path)
+        mock_osutils = mock.Mock()
+        mock_get_os_utils.return_value = mock_osutils
+        mock_exists.side_effect = os_exists_effects
+        mock_is_dir.return_value = is_dir
+        expected_logs = ["Writing userdata to: %s" % mock_user_data_path]
+        if not is_dir:
+            self.assertRaises(
+                exception.CloudbaseInitException,
+                self._userdata._write_userdata,
+                mock_userdata, mock_user_data_path)
+            return
+        with mock.patch('cloudbaseinit.plugins.common.userdata'
+                        '.open', create=True):
+            with testutils.LogSnatcher('cloudbaseinit.plugins.common.'
+                                       'userdata') as snatcher:
+                self._userdata._write_userdata(mock_userdata,
+                                               mock_user_data_path)
+        self.assertEqual(snatcher.output, expected_logs)
+
+    def test_write_userdata_fail(self):
+        self._test_write_userdata(is_dir=False)
+
+    def test_write_userdata(self):
+        self._test_write_userdata(os_exists_effects=(False, True))
+
     @mock.patch('cloudbaseinit.plugins.common.userdata.UserDataPlugin'
                 '._process_user_data')
     def _test_execute(self, mock_process_user_data, ret_val):
@@ -101,6 +138,13 @@ class UserDataPluginTest(unittest.TestCase):
         self.assertEqual(response, mock_message_from_string().walk())
         self.assertEqual(expected_logging, snatcher.output)
 
+    def test_get_header(self):
+        fake_data = "fake-user-data"
+        self.assertEqual(fake_data, self._userdata._get_headers(fake_data))
+        fake_data = None
+        with self.assertRaises(exception.CloudbaseInitException):
+            self._userdata._get_headers(fake_data)
+
     @mock.patch('cloudbaseinit.plugins.common.userdataplugins.factory.'
                 'load_plugins')
     @mock.patch('cloudbaseinit.plugins.common.userdata.UserDataPlugin'
@@ -169,10 +213,7 @@ class UserDataPluginTest(unittest.TestCase):
         mock_part.get_content_type.assert_called_once_with()
         mock_user_handlers.get.assert_called_once_with(
             _content_type)
-        if handler_func and handler_func is Exception:
-            self.assertEqual(2, mock_part.get_content_type.call_count)
-            self.assertEqual(2, mock_part.get_filename.call_count)
-        elif handler_func:
+        if handler_func:
             handler_func.assert_called_once_with(None, _content_type,
                                                  mock_part.get_filename(),
                                                  mock_part.get_payload())
@@ -208,6 +249,19 @@ class UserDataPluginTest(unittest.TestCase):
         self._test_process_part(handler_func=None,
                                 user_data_plugin=user_data_plugin,
                                 content_type=False)
+        self._test_process_part(handler_func=None,
+                                user_data_plugin=None,
+                                content_type=False)
+
+    def test_process_part_exception_occurs(self):
+        mock_part = mock_handlers = mock.MagicMock()
+        mock_handlers.get.side_effect = Exception
+        mock_part.get_content_type().side_effect = Exception
+        self.assertEqual((1, False),
+                         self._userdata._process_part(
+                         part=mock_part,
+                         user_data_plugins=None,
+                         user_handlers=mock_handlers))
 
     @mock.patch('cloudbaseinit.plugins.common.userdata.UserDataPlugin'
                 '._begin_part_process_event')
