@@ -16,6 +16,11 @@ import abc
 
 import six
 
+SAN_POLICY_UNKNOWN = 0
+SAN_POLICY_ONLINE = 1
+SAN_POLICY_OFFLINE_SHARED = 2
+SAN_POLICY_OFFLINE = 3
+
 
 @six.add_metaclass(abc.ABCMeta)
 class BaseStorageManager(object):
@@ -23,3 +28,11 @@ class BaseStorageManager(object):
     @abc.abstractmethod
     def extend_volumes(self, volume_indexes=None):
         pass
+
+    @abc.abstractmethod
+    def get_san_policy(self):
+        pass
+
+    @abc.abstractmethod
+    def set_san_policy(self, san_policy):
+        pass
